﻿using System;
using System.Collections.Generic;
using System.Data.Services;
using System.Data.Services.Common;
using System.Linq;
using System.ServiceModel.Web;

namespace ODataTour {
  public class ODataService : DataService<NorthwindIBEntities> {

    // This method is called only once to initialize service-wide policies.
    public static void InitializeService(DataServiceConfiguration config) {

      // TODO: set rules to indicate which entity sets and service operations are visible, updatable, etc.
      // Examples:
      // config.SetEntitySetAccessRule("MyEntityset", EntitySetRights.AllRead);
      // config.SetServiceOperationAccessRule("MyServiceOperation", ServiceOperationRights.All);

      config.SetEntitySetAccessRule("Customers", EntitySetRights.All);
      config.SetEntitySetAccessRule("Orders", EntitySetRights.All);
      config.SetServiceOperationAccessRule("GetOrdersByCity", ServiceOperationRights.AllRead);
      config.SetServiceOperationAccessRule("GetEmployeeSalesForPeriod", ServiceOperationRights.AllRead);
      config.DataServiceBehavior.MaxProtocolVersion = DataServiceProtocolVersion.V2;
    }

 
    /// <summary>
    /// A service operation which performs an arbitrary query.
    /// To invoke:  http://localhost:9009/ODataService.svc/GetOrdersByCity?city='Berlin'
    /// </summary>
    [WebGet]
    public IQueryable<Order> GetOrdersByCity(string city) {
      var mgr = this.CurrentDataSource;
      return mgr.Orders.Where(o => o.ShipCity == city);
    }

    /// <summary>
    /// A service operation which calls a stored procedure query.
    /// To invoke:  http://localhost:9009/ODataService.svc/GetEmployeeSalesForPeriod?startDate='1/1/1996'&endDate='12/31/1996'
    /// </summary>
    [WebGet]
    public IEnumerable<EmployeeSalesByCountry_Result> GetEmployeeSalesForPeriod(string startDate, string endDate) {
      var mgr = this.CurrentDataSource;
      var dt1 = DateTime.Parse(startDate);
      var dt2 = DateTime.Parse(endDate);
      return mgr.EmployeeSalesByCountry(dt1, dt2);
    }

  }
}